MutationFetcher<T, V> typedef

MutationFetcher<T, V> = Future<T> Function(V variables)

Function signature for mutation fetchers T is the return type of the mutation V is the type of variables passed to the mutation

Implementation

typedef MutationFetcher<T, V> = Future<T> Function(V variables);