QueryError class

Custom error class for query-related errors

Inheritance

Constructors

QueryError(String message, {Object? originalError, StackTrace? originalStackTrace, String? queryKey})

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
final
originalError Object?
final
originalStackTrace StackTrace?
final
queryKey String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
The stack trace at the point where this error was first thrown.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited