QueryStatus enum

Defines the various statues a query can be in

Inheritance
Available extensions

Values

idle → const QueryStatus

The query has not started or has been reset

loading → const QueryStatus

The query is currently fetching data

success → const QueryStatus

The query has successfully fetched data

error → const QueryStatus

The query encountered an error during data fetching

stale → const QueryStatus

The query has data, but it is considered stale and might be refetched in the background.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<QueryStatus>
A constant List of the values in this enum, in order of their declaration.