InfiniteQueryState<T> class
- Annotations
Constructors
-
InfiniteQueryState.error(Object error, [List<
QueryPage< ? previousPages])T> > -
factory
- InfiniteQueryState.idle()
-
factory
-
InfiniteQueryState.loading([List<
QueryPage< ? previousPages])T> > -
factory
-
InfiniteQueryState.refreshing(List<
QueryPage< currentPages)T> > -
factory
-
InfiniteQueryState.success(List<
QueryPage< pages, {bool isStale = false, bool hasNextPage = false})T> > -
factory
Properties
- error → Object?
-
final
- hasData → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasNextPage → bool
-
final
- hasNoData → bool
-
Checks if the infinite query has no data loaded
no setter
- isError → bool
-
no setter
- isFetchingNextPage → bool
-
final
- isIdle → bool
-
no setter
- isLoading → bool
-
no setter
- isStale → bool
-
final
- isSuccess → bool
-
no setter
- lastFetched → DateTime?
-
final
- lastRefreshError → Object?
-
final
-
pages
→ List<
QueryPage< T> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → QueryStatus
-
final
- totalItemCount → int
-
Gets the total number of items across all pages (assumes T is List
no setter
Methods
-
copyWith(
{List< QueryPage< ? pages, Object? error, QueryStatus? status, bool? isStale, DateTime? lastFetched, bool? isFetchingNextPage, bool? hasNextPage}) → InfiniteQueryState<T> >T> -
getAllItems<
E> () → List< E> - Gets all data flattened into a single list (assumes T is List
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited