RetryConfig class
Retry configuration for failed requests
Constructors
Properties
- attempts → int
-
Number of retry attempts
final
- delay → Duration
-
Base delay between retries
final
- exponentialBackoff → bool
-
Whether delay should increase exponentially
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxDelay → Duration
-
Maximum delay between retries
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shouldRetry → bool Function(Object error)?
-
Function to determine if error should be retried
final
Methods
-
getDelay(
int attempt) → Duration - Get delay for specific attempt
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited