Value<T> class
A wrapper class used in copyWith to distinguish between a null value being explicitly provided and a parameter being omitted.
If a copyWith parameter is of type Value<T>?:
nullmeans the parameter was omitted (keep existing value).Value(null)means explicitly set the field to null.Value(someValue)means set the field tosomeValue.
Constructors
- Value(T value)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → T
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited